# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.22.4](https://github.com/conda/rattler/compare/rattler_shell-v0.22.3...rattler_shell-v0.22.4) - 2024-10-07

### Other

- updated the following local packages: rattler_conda_types

## [0.22.3](https://github.com/conda/rattler/compare/rattler_shell-v0.22.2...rattler_shell-v0.22.3) - 2024-10-03

### Other

- updated the following local packages: rattler_conda_types

## [0.22.2](https://github.com/conda/rattler/compare/rattler_shell-v0.22.1...rattler_shell-v0.22.2) - 2024-09-23

### Other

- updated the following local packages: rattler_conda_types

## [0.22.1](https://github.com/conda/rattler/compare/rattler_shell-v0.22.0...rattler_shell-v0.22.1) - 2024-09-09

### Other

- updated the following local packages: rattler_conda_types

## [0.22.0](https://github.com/conda/rattler/compare/rattler_shell-v0.21.8...rattler_shell-v0.22.0) - 2024-09-05

### Fixed
- remaining typos ([#854](https://github.com/conda/rattler/pull/854))
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.21.8](https://github.com/conda/rattler/compare/rattler_shell-v0.21.7...rattler_shell-v0.21.8) - 2024-09-03

### Other
- make PackageCache multi-process safe ([#837](https://github.com/conda/rattler/pull/837))

## [0.21.7](https://github.com/conda/rattler/compare/rattler_shell-v0.21.6...rattler_shell-v0.21.7) - 2024-09-02

### Other
- updated the following local packages: rattler_conda_types

## [0.21.6](https://github.com/conda/rattler/compare/rattler_shell-v0.21.5...rattler_shell-v0.21.6) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.21.5](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.21.4...rattler_shell-v0.21.5) - 2024-08-06

### Other
- updated the following local packages: rattler_conda_types

## [0.21.4](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.21.3...rattler_shell-v0.21.4) - 2024-08-02

### Other
- updated the following local packages: rattler_conda_types

## [0.21.3](https://github.com/conda/rattler/compare/rattler_shell-v0.21.2...rattler_shell-v0.21.3) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.21.2](https://github.com/conda/rattler/compare/rattler_shell-v0.21.1...rattler_shell-v0.21.2) - 2024-07-23

### Other
- updated the following local packages: rattler_conda_types

## [0.21.1](https://github.com/conda/rattler/compare/rattler_shell-v0.21.0...rattler_shell-v0.21.1) - 2024-07-15

### Other
- update Cargo.toml dependencies

## [0.21.0](https://github.com/conda/rattler/compare/rattler_shell-v0.20.9...rattler_shell-v0.21.0) - 2024-07-08

### Added
- add direct url repodata building ([#725](https://github.com/conda/rattler/pull/725))
- allow passing custom environment to run_activation ([#743](https://github.com/conda/rattler/pull/743))

## [0.20.9](https://github.com/conda/rattler/compare/rattler_shell-v0.20.8...rattler_shell-v0.20.9) - 2024-06-06

### Other
- make `prefix_paths_entries` pub ([#729](https://github.com/conda/rattler/pull/729))

## [0.20.8](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.20.7...rattler_shell-v0.20.8) - 2024-06-04

### Fixed
- nushell environment variable quoting ([#719](https://github.com/baszalmstra/rattler/pull/719))

## [0.20.7](https://github.com/conda/rattler/compare/rattler_shell-v0.20.6...rattler_shell-v0.20.7) - 2024-06-03

### Other
- updated the following local packages: rattler_conda_types

## [0.20.6](https://github.com/conda/rattler/compare/rattler_shell-v0.20.5...rattler_shell-v0.20.6) - 2024-05-28

### Other
- updated the following local packages: rattler_conda_types

## [0.20.5](https://github.com/conda/rattler/compare/rattler_shell-v0.20.4...rattler_shell-v0.20.5) - 2024-05-27

### Other
- updated the following local packages: rattler_conda_types

## [0.20.4](https://github.com/conda/rattler/compare/rattler_shell-v0.20.3...rattler_shell-v0.20.4) - 2024-05-14

### Added
- exclude repodata records based on timestamp ([#654](https://github.com/conda/rattler/pull/654))

## [0.20.3](https://github.com/conda/rattler/compare/rattler_shell-v0.20.2...rattler_shell-v0.20.3) - 2024-05-13

### Other
- updated the following local packages: rattler_conda_types

## [0.20.2](https://github.com/conda/rattler/compare/rattler_shell-v0.20.1...rattler_shell-v0.20.2) - 2024-05-06

### Other
- updated the following local packages: rattler_conda_types

## [0.20.1](https://github.com/conda/rattler/compare/rattler_shell-v0.20.0...rattler_shell-v0.20.1) - 2024-04-25

### Fixed
- compare `UrlOrPath` ([#618](https://github.com/conda/rattler/pull/618))

## [0.20.0](https://github.com/conda/rattler/compare/rattler_shell-v0.19.6...rattler_shell-v0.20.0) - 2024-04-19

### Fixed
- unicode activation issues on windows ([#604](https://github.com/conda/rattler/pull/604))

## [0.19.6](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.19.5...rattler_shell-v0.19.6) - 2024-04-05

### Fixed
- run post-link scripts ([#574](https://github.com/baszalmstra/rattler/pull/574))

## [0.19.5](https://github.com/conda/rattler/compare/rattler_shell-v0.19.4...rattler_shell-v0.19.5) - 2024-03-30

### Other
- updated the following local packages: rattler_conda_types

## [0.19.4](https://github.com/conda/rattler/compare/rattler_shell-v0.19.3...rattler_shell-v0.19.4) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.19.3](https://github.com/conda/rattler/compare/rattler_shell-v0.19.2...rattler_shell-v0.19.3) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.2](https://github.com/conda/rattler/compare/rattler_shell-v0.19.1...rattler_shell-v0.19.2) - 2024-03-08

### Fixed
- better handle utf8 paths in CmdExe and Powershell ([#561](https://github.com/conda/rattler/pull/561))

## [0.19.1](https://github.com/conda/rattler/compare/rattler_shell-v0.19.0...rattler_shell-v0.19.1) - 2024-03-06

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/conda/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_shell-v0.18.0...rattler_shell-v0.19.0) - 2024-02-26
